Rename LinuxBIOS to coreboot

Corresponding to flashrom svn r178 and coreboot v2 svn r3054.

Signed-off-by: Stefan Reinauer <stepan@coresystems.de>
Acked-by: Stefan Reinauer <stepan@coresystems.de>
diff --git a/layout.c b/layout.c
index cbd8791..3d24b25 100644
--- a/layout.c
+++ b/layout.c
@@ -46,7 +46,7 @@
 		return 0;
 	}
 
-	printf_debug("LinuxBIOS last image size "
+	printf_debug("coreboot last image size "
 		     "(not ROM size) is %d bytes.\n", *walk);
 
 	walk--;
@@ -57,7 +57,7 @@
 	printf_debug("Mainboard ID: %s\n", mainboard_part);
 
 	/*
 	 * If lb_vendor is not set, the linuxbios table was
 	 * not found. Nor was -mVENDOR:PART specified
 	 */
@@ -57,7 +57,7 @@
 
 	/*
-	 * If lb_vendor is not set, the linuxbios table was
+	 * If lb_vendor is not set, the coreboot table was
 	 * not found. Nor was -mVENDOR:PART specified
 	 */